﻿//-----------------------------------------------------------------------
// <copyright file="Wiki.cs" company="BME MIT">
//     Simple Wiki server.
//     Created by Daniel Darvas, BME MIT FTSRG, 2012.
//     Website: https://www.inf.mit.bme.hu/edu/bsc/irf
// </copyright>
//-----------------------------------------------------------------------

using System.Configuration;

namespace MicroWiki
{
    /// <summary>
    /// Simple Wiki server.
    /// Created by Daniel Darvas, BME MIT FTSRG, 2012.
    /// </summary>
    public class Wiki
    {
        /// <summary>
        /// The Wiki engine instance.
        /// </summary>
        private WikiServer wikiServer = new WikiServer();

        /// <summary>
        /// Gets a value indicating whether the server is running or not.
        /// </summary>
        public bool ServerRunning
        {
            get
            {
                return this.wikiServer.Running;
            }
        }

        /// <summary>
        /// Gets the listening port of the server.
        /// </summary>
        public int Port
        {
            get
            {
                return this.wikiServer.Port;
            }
        }

        /// <summary>
        /// Regularly poll the feeds and keep them upto date
        /// this method should be called in a separate thread.
        /// </summary>
        public void Run()
        {
            try
            {
                this.LoadConfiguration(this.wikiServer);
                this.wikiServer.Run();
                while (true)
                {
                    System.Threading.Thread.Sleep(1000);
                }
            }
            finally
            {
                this.wikiServer.Stop();
            }
        }

        /// <summary>
        /// Loads the configuration for the given server from app.config.
        /// </summary>
        /// <param name="server">The server to configure.</param>
        private void LoadConfiguration(WikiServer server)
        {
            server.Templates = ConfigurationManager.AppSettings["TemplatePath"];
            server.DefaultPage = ConfigurationManager.AppSettings["Default"];
            server.WebRootPath = ConfigurationManager.AppSettings["WebRoot"];
            server.Port = int.Parse(ConfigurationManager.AppSettings["Port"]);
        }
    }
}
