﻿//-----------------------------------------------------------------------
// <copyright file="WikiHelper.cs" company="BME MIT">
//     Simple Wiki server.
//     Created by Daniel Darvas, BME MIT FTSRG, 2012.
//     Website: https://www.inf.mit.bme.hu/edu/bsc/irf
// </copyright>
//-----------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.Text;
using System.Text.RegularExpressions;

namespace MicroWiki
{
    /// <summary>
    /// Static helper class for common Wiki-related operations.
    /// </summary>
    public static class WikiHelper
    {
        /// <summary>
        /// Replaces the links in a wiki page to HTML formatted links.
        /// </summary>
        /// <param name="content">The content to be modified.</param>
        /// <returns>The content where all links are replaced to HTML hyperlinks.</returns>
        public static string ReplaceLinks(string content)
        {
            MatchEvaluator linkReplace = delegate(Match match)
            {
                string pagename = match.Value.Replace("[", string.Empty).Replace("]", string.Empty);
                if (pagename.StartsWith("http://", StringComparison.InvariantCultureIgnoreCase))
                {
                    // absolute path
                    return string.Format("<a href='{0}'>{0}</a>", pagename);
                }
                else
                {
                    // relative path
                    return string.Format("<a href='/wiki/{0}'>{0}</a>", pagename);
                }
            };

            content = Regex.Replace(content, @"\[(.+?)\]", linkReplace);
            return content;
        }

        /// <summary>
        /// Replaces the format signs in a wiki page to HTML format tags.
        /// </summary>
        /// <param name="content">The content to be modified.</param>
        /// <returns>The content where all format signs are replaced to HTML format tags.</returns>
        public static string ReplaceFormatSigns(string content)
        {
            MatchEvaluator italicReplace = delegate(Match match)
            {
                string pagename = match.Value.Replace("_", string.Empty);
                return string.Format("<i>{0}</i>", pagename);
            };
            content = Regex.Replace(content, @"\b_(.+?)_\b", italicReplace);

            MatchEvaluator boldReplace = delegate(Match match)
            {
                string pagename = match.Value.Replace("*", string.Empty);
                return string.Format("<b>{0}</b>", pagename);
            };
            content = Regex.Replace(content, @"\*(.+?)\*", boldReplace);

            MatchEvaluator headingReplace = delegate(Match match)
            {
                string pagename = match.Value.Replace("==", string.Empty);
                return string.Format("<h2>{0}</h2>", pagename);
            };
            content = Regex.Replace(content, @"==(.+?)==", headingReplace);
            return content;
        }
    }
}
